package
Version:
v0.2.0
Opens a new window with list of versions in this module.
Published: Mar 3, 2026
License: Apache-2.0
Opens a new window with license information.
Imports: 3
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
Code generated by Configen. DO NOT EDIT.
type Config struct {
ValueA struct {
ValueB string `config:"value_b"`
ValueC struct {
ValueD struct {
ValueE string `config:"value_e"`
ValueF string `config:"value_f"`
} `config:"value_d"`
} `config:"value_c"`
} `config:"value_a"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.